# -*- coding: utf-8 -*-
#______________________________________________________________________________
# SpeciesDict -----------------------------------------------------------------
# This dictionaries contains information about the species and VSS model
# parameters for the species that can be used in the Sparta simulations. If a
# new species needs to be used that is not in the list it needs to be added to
# the dictionary.
#------------------------------------------------------------------------------

SpeciesDict = {
        'Info'        : [       'Name', 'Molwt',  'Molmass', 'Rot DoF', 'IRoReN', 'Vib DoF',   'IViReN', 'VibT', 'Species wt', 'Charge',  'Diameter', 'Omega', 'Tref', 'Alpha'],
        'LiMon'       : [      'LiMon',   6.941, 1.1526E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,    4.62E-10,   0.752,  800.0,     1.0],
        'LiSat'       : [      'LiSat',   6.941, 1.1526E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0, 4.38293E-10,  0.5467,  800.0,     1.0],
        'LiVHS'       : [      'LiVHS',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   5.418E-10,   0.948,  850.0,     1.0],
        'LiVHSp10'    : [   'LiVHSp10',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   5.959E-10,   0.948,  850.0,     1.0],
        'LiVHSm10'    : [   'LiVHSm10',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   4.926E-10,   0.948,  850.0,     1.0],
        'LiVSS'       : [   'LiVSS   ',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   5.346E-10,   0.948,  850.0,   1.284],
        'LiVSSp10'    : [   'LiVSSp10',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   4.881E-10,   0.948,  850.0,   1.284],
        'LiVSSm10'    : [   'LiVSSm10',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   4.860E-10,   0.948,  850.0,   1.284],
        'LiHybSatNar' : ['LiHybSatNar',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,  4.9996E-10,   0.740,  850.0,     1.0],
        'LiHybSatWid' : ['LiHybSatWid',    6.94, 1.1524E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,   5.212E-10,   0.813,  850.0,     1.0],
        'H2'          : [         'H2',     2.0,   3.34E-27,         2,      0.2,         2,     2.5E-5, 6159.0,          1.0,      0.0,    2.88E-10,    0.67, 273.15,    1.35],
        'O2'          : [         'O2',   32.00,   5.31E-26,         2,      0.2,         2, 5.58659E-5, 2256.0,          1.0,      0.0,    3.96E-10,    0.77, 273.15,     1.4],
        'N2'          : [         'N2',  28.016,   4.65E-26,         2,      0.2,         2, 1.90114E-5, 3371.0,          1.0,      0.0,    4.07E-10,    0.74, 273.15,     1.6],
        'H'           : [          'H',     1.0,   1.67E-27,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,        '-' ,     '-',    '-',     '-'],
        'O'           : [          'O',   16.00,   2.65E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,     3.0E-10,    0.80, 273.15,     1.0],
        'N'           : [          'N',  14.008,  2.325E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      0.0,     3.0E-10,    0.80, 273.15,     1.0],
        'NO'          : [         'NO',  30.008,   4.98E-26,         2,      0.2,         2, 7.14285E-5, 2719.0,          1.0,      0.0,     4.0E-10,    0.80, 273.15,     1.0],
        'H2+'         : [        'H2+',     2.0,   3.34E-27,         2,      0.2,         2,     2.5E-5, 6159.0,          1.0,      1.0,    2.88E-10,    0.67, 273.15,    1.35],
        'O2+'         : [        'O2+',   32.00,   5.31E-26,         2,      0.2,         2, 5.58659E-5, 2256.0,          1.0,      1.0,    3.96E-10,    0.77, 273.15,     1.4],
        'N2+'         : [        'N2+',  28.016,   4.65E-26,         2,      0.2,         2, 1.90114E-5, 3371.0,          1.0,      1.0,    4.07E-10,    0.74, 273.15,     1.6],
        'H+'          : [         'H+',     1.0,   1.67E-27,         0,      0.0,         0,        0.0,    0.0,          1.0,      1.0,        '-' ,     '-',    '-',     '-'],
        'O+'          : [         'O+',   16.00,   2.65E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      1.0,     3.0E-10,    0.80, 273.15,     1.0],
        'N+'          : [         'N+',  14.008,  2.325E-26,         0,      0.0,         0,        0.0,    0.0,          1.0,      1.0,     3.0E-10,    0.80, 273.15,     1.0],
        'NO+'         : [        'NO+',  30.008,   4.98E-26,         2,      0.2,         2, 7.14285E-5, 2719.0,          1.0,      1.0,     4.0E-10,    0.80, 273.15,     1.0],
        'e'           : [          'e',   0.001, 9.1094E-31,         0,      0.0,         0,        0.0,    0.0,          1.0,     -1.0,     7.0E-13,    0.50, 273.15,     1.0],
}
